@@ -31,14 +31,10 @@ def cut(path, limit=19):
 		yield fn
 
 def getCutImages(images, limit=9):
-	os.system('mkdir tmp_image > /dev/null 2>&1')
 	result = []
-	prefix = 'tmp_image/'
 	for image in images:
-		fn = prefix + os.path.basename(image.replace('=', '.'))
-		with open(fn, 'wb') as f:
-			f.write(cached_url.get(image, force_cache=True, mode='b'))
-		cuts = list(cut(fn))
+		cached_url.get(image, force_cache=True, mode='b')
+		cuts = list(cut(cached_url.getFilePath(image)))
 		if not cuts:
 			cuts = [fn]
 		for c in cuts:
